/*
 * Copyright (c) 2024 ShinGeTsu Meter.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */
#pragma once

// GPOIO
#define LED_PIN      25
#define TA_RE1       9
#define TA_RE2       10
#define BUTTON_RST   11
#define BUTTON_COUNT 12
#define BUTTON_AUTO  13

// ロータリーエンコーダ移動方向判定用
#define ROTARY_DIRECTION \
    { 0, 1, -1, 0, -1, 0, 0, 1, 1, 0, 0, -1, 0, -1, 1, 0 }

// TA計算用定数
#define TA_MAX 6.5
#define TA_MIN 0.9412

// 時間
#define SAMPLE_WAIT_uS (50 * 1000)     // サンプリング間隔 50[ms]
#define UPDATE_WAIT_uS (500 * 1000)    // LCD更新間隔 500[ms]
#define RESET_WAIT_uS  (500 * 1000)    // この期間連続して範囲外にであった場合リセットを実行
#define EVENT_BLOCK_uS (10 * 1000)     // 同じイベントの連続実行を抑止する時間 10[ms]

// TA履歴
#define HIST_uS      (1500 * 1000)                 // 履歴保存期間[mS]
#define TA_HIST_SIZE (HIST_uS / SAMPLE_WAIT_uS)    // TA履歴サイズ
#define TA_BLOCK_TH  0.800                         // 履歴中のTA範囲がこれより大きい場合、自動リセット/TAカウントを抑制

// 電圧
#define METER_MAX_RATIO (1.0 / 13.0 * 36.5)    // セット位置とリセット閾値の比率。13:セット位置のメモリ、36:リセット位置のメモリ

// 表示モード
typedef enum {
    VIEW_1 = 0,
    VIEW_2,
    VIEW_3,
} view_t;
